{------------------------------------------------------------------------------}
{ Copyright             :  Copyright 1996 by Y. Rochat                        }
{ Date de creation      : 14/12/1995                                           }
{ Last Update           : 23/01/1996                                           }
{ Version Number        : 1.10                                                 }
{ Langage Programmation : DELPHI 1.01                                          }
{------------------------------------------------------------------------------}
{ YRNAG.PAS   					: A NagScreen COMPONENT for DELPHI that allow you to   }
{                         easily implement a Nag screen for your projects.     }
{                         When invoked by a call to the ShowNag method, it will}
{                         display your shareware information in a TMemo box for}
{                         WaitTime seconds. This information must be written in}
{                         a text file called 'comments.txt' and located in the }
{                         main directory of your project as the file 'icon.bmp'}
{                         which is the icon of your application.               }
{                                                                              }
{                         You can invoke the Nag's Screen through the main     }
{                         form's OnCreate or OnShow event handlers.            }
{                                                                              }
{ HOW TO USE IT : 1) Put a TYRNagScreen (by ex. MyNag) in your main Delphi form}
{                 2) Make a call to MyNag.ShowNag to invoke the Nag's Screen   }
{------------------------------------------------------------------------------}
{                               IMPORTANT                                      }
{                                                                              }
{ You can use this code as is and you are FREE to copy/distribute provided that}
{ this notice is not modified and included in the distrubution pack.           }
{ I'll be more than happy to hear from you for your comments about a real-life }
{ use of this code. Please send your comments to " rochat@dma.epfl.ch " with   }
{ subject field starting with the words 'TYRNAG'.                              }
{------------------------------------------------------------------------------}
{:DISCLAIMER:                                                                  }
{------------                                                                  }
{  THIS SOURCE CODE IS DELIVERED AS IS. THERE IS NO REASON TO THINK THAT IT    }
{  SHOULD NOT WORK AS CLAIMED. BUT JUST IN CASE, LET ME DISCLAIM THAT YVES     }
{  ROCHAT CAN NOT BE HELD LIABLE IF YOU LOOSE TIME OR MONEY USING THIS CODE.   }
{------------------------------------------------------------------------------}

UNIT YRNag ;

{---------------------------------------------------------------------------}
{                                                                           }
{         PARTIE INTERFACE : SECTION PUBLIQUE OU VISIBLE DE L'UNITE         }
{                                                                           }
{---------------------------------------------------------------------------}

INTERFACE

USES
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics,
  Controls, Forms, Dialogs, YRNagFrm ;

type
  TYRNagScreen = class(TComponent)
  private
    { Private declarations }
    FProductName	: string;
    FVersion			: string;
    FCopyRight		: string;
    FAuthor				: string;
    FAddress			: string;
    FCityCode   	: string;
    FTitle				: string;
    FWaitTime			: Byte ;
    function SetWaitTime(AVal : Byte) : Byte ;
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    function    ShowNag : Boolean ;
  published
    { Published declarations }
    property ProductName	: string 	read FProductName write FProductName;
    property Version			: string 	read FVersion write FVersion;
    property CopyRight		: string 	read FCopyRight write FCopyRight;
    property Author				: string 	read FAuthor write FAuthor;
    property Address			: string 	read FAddress write FAddress;
    property CityCode	    : string 	read FCityCode write FCityCode;
    property Title				: string	read FTitle write FTitle;
    property WaitTime     : Byte		read FWaitTime write SetWaitTime ;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('ToolsY', [TYRNagScreen]);
end;

constructor TYRNagScreen.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FProductName	:= 'Nom du Produit' ;
  FVersion			:= 'Version 1.1' ;
  FCopyRight		:= ' Copyright 1996' ;
  FAuthor				:= 'Yves Rochat' ;
  FAddress			:= 'Chemin de la Clergre 36' ;
  FCityCode     := 'Ch-1009 PULLY (Vaud)' ;
  FTitle				:= 'Titre du dialogue' ;
  FWaitTime			:= 10 ;
end ;

function TYRNagScreen.SetWaitTime(AVal : Byte) : Byte ;
begin
  If AVal > 60
  	then	FWaitTime := 60
    else	FWaitTime := Aval ;
end ;

function TYRNagScreen.ShowNag : Boolean ;
var FileName : String ;
begin
  try
    FormNag := TFormNag.Create(Application);
    FormNag.Caption								:= FTitle ;
    FormNag.ProgramIcon.Picture.LoadFromFile('icon.bmp') ;
    FormNag.SetDetails(FProductName,FVersion,
                       FCopyRight + ' by ' + FAuthor,
                       FAddress,FCityCode);
    FileName := UpperCase(ExtractFilePath(Application.ExeName) + 'comments.txt') ;
    FormNag.Licence.Lines.LoadFromFile(FileName);
    FormNag.Maxtime 							:= FWaitTime ;
    FormNag.SetData(Self) ;
    FormNag.ShowModal;
  finally
    FormNag.Free;
  end;
end;

end.
